Quantcast
Channel: Serverphorums.com - HAProxy
Viewing all 5112 articles
Browse latest View live

[PATCH v2] BUG/MINOR: log: Don't use strftime() which can clobber timezone if chrooted (no replies)

$
0
0
From 65198ff81545bd146511511eda534c699cb100b7 Mon Sep 17 00:00:00 2001
From: Benoit GARNIER <chezbunch+haproxy@gmail.com>
Date: Sun, 27 Mar 2016 03:04:16 +0200
Subject: [PATCH] BUG/MINOR: log: Don't use strftime() which can clobber
timezone if chrooted

The strftime() function can call tzset() internally on some platforms.
When haproxy is chrooted, the /etc/localtime file is not found, and some
implementations will clobber the content of the current timezone.

The GMT offset is computed by diffing the times returned by gmtime_r() and
localtime_r(). These variants are guaranteed to not call tzset() and were
already used in haproxy while chrooted, so they should be safe.

This patch must be backported to 1.6 and 1.5.
---
include/common/standard.h | 6 ++--
src/log.c | 4 +--
src/standard.c | 76 ++++++++++++++++++++++++++++++++++-------------
3 files changed, 62 insertions(+), 24 deletions(-)

diff --git a/include/common/standard.h b/include/common/standard.h
index 353d0b0..cd2208c 100644
--- a/include/common/standard.h
+++ b/include/common/standard.h
@@ -871,10 +871,11 @@ extern const char *monthname[];
char *date2str_log(char *dest, struct tm *tm, struct timeval *date, size_t size);

/* Return the GMT offset for a specific local time.
+ * Both t and tm must represent the same time.
* The string returned has the same format as returned by strftime(... "%z", tm).
* Offsets are kept in an internal cache for better performances.
*/
-const char *get_gmt_offset(struct tm *tm);
+const char *get_gmt_offset(time_t t, struct tm *tm);

/* gmt2str_log: write a date in the format :
* "%02d/%s/%04d:%02d:%02d:%02d +0000" without using snprintf
@@ -885,10 +886,11 @@ char *gmt2str_log(char *dst, struct tm *tm, size_t size);

/* localdate2str_log: write a date in the format :
* "%02d/%s/%04d:%02d:%02d:%02d +0000(local timezone)" without using snprintf
+ * Both t and tm must represent the same time.
* return a pointer to the last char written (\0) or
* NULL if there isn't enough space.
*/
-char *localdate2str_log(char *dst, struct tm *tm, size_t size);
+char *localdate2str_log(char *dst, time_t t, struct tm *tm, size_t size);

/* These 3 functions parses date string and fills the
* corresponding broken-down time in <tm>. In succes case,
diff --git a/src/log.c b/src/log.c
index ab38353..4d496cd 100644
--- a/src/log.c
+++ b/src/log.c
@@ -979,7 +979,7 @@ static char *update_log_hdr_rfc5424(const time_t time)

tvsec = time;
get_localtime(tvsec, &tm);
- gmt_offset = get_gmt_offset(&tm);
+ gmt_offset = get_gmt_offset(time, &tm);

hdr_len = snprintf(logheader_rfc5424, global.max_syslog_len,
"<<<<>1 %4d-%02d-%02dT%02d:%02d:%02d%.3s:%.2s %s ",
@@ -1495,7 +1495,7 @@ int build_logline(struct stream *s, char *dst, size_t maxsize, struct list *list

case LOG_FMT_DATELOCAL: // %Tl
get_localtime(s->logs.accept_date.tv_sec, &tm);
- ret = localdate2str_log(tmplog, &tm, dst + maxsize - tmplog);
+ ret = localdate2str_log(tmplog, s->logs.accept_date.tv_sec, &tm, dst + maxsize - tmplog);
if (ret == NULL)
goto out;
tmplog = ret;
diff --git a/src/standard.c b/src/standard.c
index e08795f..2fe92ba 100644
--- a/src/standard.c
+++ b/src/standard.c
@@ -2552,31 +2552,66 @@ char *date2str_log(char *dst, struct tm *tm, struct timeval *date, size_t size)
return dst;
}

+/* Base year used to compute leap years */
+#define TM_YEAR_BASE 1900
+
+/* Return the difference in seconds between two times (leap seconds are ignored).
+ * Retrieved from glibc 2.18 source code.
+ */
+static int my_tm_diff(const struct tm *a, const struct tm *b)
+{
+ /* Compute intervening leap days correctly even if year is negative.
+ * Take care to avoid int overflow in leap day calculations,
+ * but it's OK to assume that A and B are close to each other.
+ */
+ int a4 = (a->tm_year >> 2) + (TM_YEAR_BASE >> 2) - ! (a->tm_year & 3);
+ int b4 = (b->tm_year >> 2) + (TM_YEAR_BASE >> 2) - ! (b->tm_year & 3);
+ int a100 = a4 / 25 - (a4 % 25 < 0);
+ int b100 = b4 / 25 - (b4 % 25 < 0);
+ int a400 = a100 >> 2;
+ int b400 = b100 >> 2;
+ int intervening_leap_days = (a4 - b4) - (a100 - b100) + (a400 - b400);
+ int years = a->tm_year - b->tm_year;
+ int days = (365 * years + intervening_leap_days
+ + (a->tm_yday - b->tm_yday));
+ return (60 * (60 * (24 * days + (a->tm_hour - b->tm_hour))
+ + (a->tm_min - b->tm_min))
+ + (a->tm_sec - b->tm_sec));
+}
+
/* Return the GMT offset for a specific local time.
+ * Both t and tm must represent the same time.
* The string returned has the same format as returned by strftime(... "%z", tm).
* Offsets are kept in an internal cache for better performances.
*/
-const char *get_gmt_offset(struct tm *tm)
+const char *get_gmt_offset(time_t t, struct tm *tm)
{
/* Cache offsets from GMT (depending on whether DST is active or not) */
static char gmt_offsets[2][5+1] = { "", "" };

- int old_isdst = tm->tm_isdst;
char *gmt_offset;
-
- /* Pretend DST not active if its status is unknown, or strftime() will return an empty string for "%z" */
- if (tm->tm_isdst < 0) {
- tm->tm_isdst = 0;
- }
-
- /* Fetch the offset and initialize it if needed */
- gmt_offset = gmt_offsets[tm->tm_isdst & 0x01];
- if (unlikely(!*gmt_offset)) {
- strftime(gmt_offset, 5+1, "%z", tm);
- }
-
- /* Restore previous DST flag */
- tm->tm_isdst = old_isdst;
+ struct tm tm_gmt;
+ int diff;
+ int isdst = tm->tm_isdst;
+
+ /* Pretend DST not active if its status is unknown */
+ if (isdst < 0)
+ isdst = 0;
+
+ /* Fetch the offset and initialize it if needed */
+ gmt_offset = gmt_offsets[isdst & 0x01];
+ if (unlikely(!*gmt_offset)) {
+ get_gmtime(t, &tm_gmt);
+ diff = my_tm_diff(tm, &tm_gmt);
+ if (diff < 0) {
+ diff = -diff;
+ *gmt_offset = '-';
+ } else {
+ *gmt_offset = '+';
+ }
+ diff /= 60; /* Convert to minutes */
+ snprintf(gmt_offset+1, 4+1, "%02d%02d", diff/60, diff%60);
+ }

return gmt_offset;
}
@@ -2616,16 +2651,17 @@ char *gmt2str_log(char *dst, struct tm *tm, size_t size)

/* localdate2str_log: write a date in the format :
* "%02d/%s/%04d:%02d:%02d:%02d +0000(local timezone)" without using snprintf
* * return a pointer to the last char written (\0) or
* * NULL if there isn't enough space.
*/
-char *localdate2str_log(char *dst, struct tm *tm, size_t size)
+char *localdate2str_log(char *dst, time_t t, struct tm *tm, size_t size)
{
const char *gmt_offset;
if (size < 27) /* the size is fixed: 26 chars + \0 */
return NULL;

- gmt_offset = get_gmt_offset(tm);
+ gmt_offset = get_gmt_offset(t, tm);

dst = utoa_pad((unsigned int)tm->tm_mday, dst, 3); // day
*dst++ = '/';
@@ -2616,16 +2651,17 @@ char *gmt2str_log(char *dst, struct tm *tm, size_t size)
/* localdate2str_log: write a date in the format :
* "%02d/%s/%04d:%02d:%02d:%02d +0000(local timezone)" without using snprintf
- * * return a pointer to the last char written (\0) or
- * * NULL if there isn't enough space.
+ * Both t and tm must represent the same time.
+ * return a pointer to the last char written (\0) or
+ * NULL if there isn't enough space.
*/
--
2.5.0

Happy New Year's Day (no replies)

$
0
0
&#22806;&#36152;&#34892;&#19994;&#25972;&#20307;&#22823;&#29615;&#22659;&#19981;&#22909;&#65292;&#20294;&#26159;&#20026;&#20160;&#20040;&#21035;&#20154;&#19994;&#32489;&#36824;&#26159;&#19968;&#24180;&#27604;&#19968;&#24180;&#39640;&#65311;
&#22806;&#36152;&#28192;&#36947;&#36873;&#25321;&#19981;&#23545;&#65292;&#21162;&#21147;&#30333;&#36153;&#65281;
&#29616;&#22312;&#36824;&#25226;B2B&#24179;&#21488;&#24403;&#20570;&#20225;&#19994;&#23458;&#25143;&#24320;&#21457;&#28192;&#36947;&#30340;&#21807;&#19968;&#36873;&#25321;&#65292;&#37027;&#24744;&#23601;&#30495;&#30340;&#35201;&#34987;OUT&#20986;&#23616;&#20102;&#65281;
&#36890;&#36807;&#20027;&#21160;&#20986;&#20987;&#30340;&#26041;&#24335;&#33719;&#24471;&#26356;&#22810;&#19982;&#22269;&#22806;&#23458;&#25143;&#27807;&#36890;&#30340;&#26426;&#20250;&#65292;&#32780;&#19981;&#34987;&#21160;&#31561;&#24453;&#23458;&#25143;&#21672;&#35810;&#65292;&#20135;&#21697;&#26356;&#24555;&#30340;&#25512;&#24191;&#20986;&#21435;&#65292;&#19994;&#21153;&#21592;&#19994;&#32489;&#26356;&#31283;&#23450;&#65292;&#20225;&#19994;&#26356;&#33391;&#24615;&#21457;&#23637;&#12290;
&#20026;&#22806;&#36152;&#20225;&#19994;&#25552;&#20379;&#24180;&#24213;&#23458;&#25143;&#24320;&#21457;&#28192;&#36947;&#25237;&#36164;&#35745;&#21010;&#12290;
&nbsp;
&#26377;&#20852;&#36259;&#30340;&#26379;&#21451;&#21152;&#25105;+1747175804&larr;QQ&#35814;&#32454;&#20102;&#35299;&#65281;&#65288;&#20844;&#21496;&#26377;&#23458;&#25143;&#25512;&#24191;&#35745;&#21010;&#30340;&#21487;&#20197;&#35814;&#32454;&#20102;&#35299;&#19968;&#19979;&#65289;

3月17-18深圳香港朗山国际酒店,南山区科技园北区朗山路 (no replies)

Re:Re: Clutch bag's introdution (no replies)

$
0
0
Dear Manager,


Good day to you.
It's time for share our new styles Clutch bags for 2016.

These bags With minimal detailing and a textured leather finish,

- Zip fastening across the top

- Leather ajustable (can be take down) shoulder strap.

- Beautiful pattern and popular shape.

- Internal zip fastened pocket for the cards and money.

-The big space can be put your Iphone ,small cosmetics etc.

- 100% leather

-our bag is an ideal day to evening option,please carry your our bag and good moon to travel with your friends.




How do you think of these bags? Please feel free to contact with me if you are interested or have some new styles to develop.

We can offer samples at first.

Look forward to hearing from you.

--

Thanks & Best regards
Candy
Sales manager
Guangzhou Shera-bag factory
Tel: 86-20 34329687
Email: candy@sherabag.com
Web: http://www.sherabag.com/
Address: Address: Rom1705 West Tower, Building C, Baoli world Trade Center, Pazhou Haizhu District Guangzhou China.

在 2016-02-17 14:08:30,"SANCIA" <info@sancia.com.au> 写道:

Hi Candy,


Thanks for sending those images through,


Are these pieces full leather? Could you give us some FOB prices and MOQ's for the pictures below?


Thanks


Angus


Angus Plate
Director


www.sancia.com.au













From: GZ Shera bag factory Candy <candy@sherabag.com>
Date: Tuesday, 16 February 2016 2:14 pm
To: SANCIA <info@sancia.com.au>
Subject: New styles for 2016



Dear Manager,


How are you and your weekend?
This is Candy from shera bag factory in Guangzhou ,China.
Glad to tell you that we have come back to the factory from Chinese New Year .
To the begining of Lunar New Year, our factory is available to receive orders and ready to produce.
Welcome your designs and welcome to choose the styles on our website.Some style for 2016 for your reference.


Wish you a good businese and look forward to get your reply.







--

Thanks & Best regards
Candy
Sales manager
Guangzhou Shera-bag factory
Tel: 86-20 34329687
Email: candy@sherabag.com
Web: http://www.sherabag.com/
Address: Address: Rom1705 West Tower, Building C, Baoli world Trade Center, Pazhou Haizhu District Guangzhou China.

[PATCH] MINOR: DeviceAtlas slight update (no replies)

$
0
0
Hi all,

Here a little update of the DeviceAtlas module which use the new wider 64
bytes ARG# macros introduced recently, plus documentations related changes.

Please cc ttrnka@deviceatlas.com for all answers.

All the best.

Kindest regards.

Reliable Butterfly Valve, Gate Valve manufacturer from Tianjin (no replies)

$
0
0
Dear&nbsp;Manager,I&nbsp;am&nbsp;Lucy&nbsp;from&nbsp;Tianjin&nbsp;World&nbsp;Machinery&nbsp;Manufacture&nbsp;Co.,&nbsp;Ltd.
We&nbsp;are&nbsp;glad&nbsp;to&nbsp;know&nbsp;you&nbsp;from&nbsp;my&nbsp;client.
As&nbsp;a&nbsp;professional&nbsp;valve&nbsp;manufacturer,&nbsp;I&nbsp;would&nbsp;like&nbsp;to&nbsp;introduce&nbsp;our&nbsp;products&nbsp;to&nbsp;you&nbsp;and&nbsp;offer&nbsp;you&nbsp;a&nbsp;quote.&nbsp;We&nbsp;manufacture&nbsp;
Butterfly&nbsp;Valve&nbsp;Gate&nbsp;Valve
Check&nbsp;Valve&nbsp;Y-Strainer
Rubber&nbsp;Expansion&nbsp;Joint&nbsp;Dismantling&nbsp;Joint
We are very competitive because we do parts process and painting
ourself and casting factory is near us.
If&nbsp;there&nbsp;is&nbsp;anything&nbsp;we&nbsp;can&nbsp;do&nbsp;for&nbsp;you,&nbsp;we&nbsp;shall&nbsp;be&nbsp;more&nbsp;than&nbsp;pleased&nbsp;to&nbsp;do&nbsp;so.
&nbsp;
Sincerely
Yours!&nbsp;Lucy


Foreign Trade&nbsp;Department&nbsp;
Tianjin&nbsp;World&nbsp;Machinery&nbsp;Manufacture&nbsp;Co.,&nbsp;Ltd
Add:&nbsp;No.9,&nbsp;Chuangye&nbsp;Road,&nbsp;Jinnan&nbsp;District,&nbsp;Tianjin,&nbsp;China.Tel:&nbsp;86-22-59848440
&nbsp; &nbsp; &nbsp; &nbsp; &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
&nbsp; Fax:86-22-59848444Mobile:&nbsp;86-15320145077 &nbsp; &nbsp;
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; &nbsp;&nbsp;Skype:
world-machinery

General SSL vs. non-SSL Performance (14 replies)

$
0
0
Hi,

this is rather HAProxy unrelated so more a general problem but anyway..
I did some tests with SSL vs. non-SSL performance and I wanted to share
my
results with you guys but also trying to solve the actual problem

So here is what I did:

haproxy.cfg:
global
user haproxy
group haproxy
maxconn 75000

ca-base /etc/ssl/certs

# Set secure global SSL options from https://cipherli.st/ and
https://bettercrypto.org/
ssl-default-bind-ciphers
ECDHE-RSA-AES128-GCM-SHA256:ECDHE-ECDSA-AES128-GCM-SHA256:ECDHE-RSA-AES256-GCM-SHA384:ECDHE-ECDSA-AES256-GCM-SHA384:DHE-DSS-AES128-GCM-SHA256:kEDH+AESGCM:ECDHE-RSA-AES128-SHA256:ECDHE-ECDSA-AES128-SHA256:ECDHE-RSA-AES128-SHA:ECDHE-ECDSA-AES128-SHA:ECDHE-RSA-AES256-SHA384:ECDHE-ECDSA-AES256-SHA384:ECDHE-RSA-AES256-SHA:ECDHE-ECDSA-AES256-SHA:DHE-DSS-AES128-SHA256:DHE-DSS-AES256-SHA:AES128-GCM-SHA256:AES256-GCM-SHA384:AES128-SHA:AES256-SHA:AES:CAMELLIA:DES-CBC3-SHA:!aNULL:!eNULL:!EXPORT:!DES:!RC4:!MD5:!PSK:!aECDH:!EDH-DSS-DES-CBC3-SHA:!EDH-RSA-DES-CBC3-SHA:!KRB5-DES-CBC3-SHA:!DHE-RSA-AES128-GCM-SHA256:!DHE-RSA-AES256-GCM-SHA384:!DHE-RSA-AES128-SHA256:!DHE-RSA-AES256-SHA:!DHE-RSA-AES128-SHA:!DHE-RSA-AES256-SHA256:!DHE-RSA-CAMELLIA128-SHA:!DHE-RSA-CAMELLIA256-SHA

ssl-default-bind-options no-sslv3 no-tls-tickets

tune.ssl.default-dh-param 1024

defaults
timeout client 300s
timeout server 300s
timeout queue 60s
timeout connect 7s
timeout http-request 10s

maxconn 75000

frontend haproxy_test
bind :65410

mode http
option httpclose

default_backend backend_test


frontend haproxy_test.ssl
bind :65420 ssl crt /etc/haproxy/ssl/test.pem

mode http
option httpclose

default_backend backend_test

backend backend_test
mode http

errorfile 503 /etc/haproxy/test.error

# vim: set syntax=haproxy:





/etc/haproxy/test.error:
HTTP/1.0 200
Cache-Control: no-cache
Connection: close
Content-Type: text/plain

Test123456






HAProxy itself has then been started with the following command:
/usr/sbin/haproxy -f /etc/haproxy/haproxy.cfg -D -p /var/run/haproxy.pid

So we have HAProxy serving very little content directly from the memory
which
means there's no actual overhead to backends, like a remote Apache or
something
like that.

A test without SSL, using "ab":
# ab -k -n 5000 -c 250 http://127.0.0.1:65410/
This is ApacheBench, Version 2.3 <$Revision: 655654 $>
Copyright 1996 Adam Twiss, Zeus Technology Ltd, http://www.zeustech.net/
Licensed to The Apache Software Foundation, http://www.apache.org/

Benchmarking 127.0.0.1 (be patient)
Completed 500 requests
Completed 1000 requests
Completed 1500 requests
Completed 2000 requests
Completed 2500 requests
Completed 3000 requests
Completed 3500 requests
Completed 4000 requests
Completed 4500 requests
Completed 5000 requests
Finished 5000 requests


Server Software:
Server Hostname: 127.0.0.1
Server Port: 65410

Document Path: /
Document Length: 11 bytes

Concurrency Level: 250
Time taken for tests: 0.117 seconds
Complete requests: 5000
Failed requests: 0
Write errors: 0
Keep-Alive requests: 0
Total transferred: 460000 bytes
HTML transferred: 55000 bytes
Requests per second: 42668.31 [#/sec] (mean)
Time per request: 5.859 [ms] (mean)
Time per request: 0.023 [ms] (mean, across all concurrent
requests)
Transfer rate: 3833.48 [Kbytes/sec] received

Connection Times (ms)
min mean[+/-sd] median max
Connect: 1 3 0.4 3 4
Processing: 1 3 0.6 3 6
Waiting: 0 2 0.7 2 4
Total: 4 6 0.3 6 7

Percentage of the requests served within a certain time (ms)
50% 6
66% 6
75% 6
80% 6
90% 6
95% 6
98% 6
99% 6
100% 7 (longest request)





Wow, ~42k requests per second, quite a lot and pretty fast as well. Now
lets see SSL:

# ab -k -n 5000 -c 250 https://127.0.0.1:65420/
This is ApacheBench, Version 2.3 <$Revision: 655654 $>
Copyright 1996 Adam Twiss, Zeus Technology Ltd, http://www.zeustech.net/
Licensed to The Apache Software Foundation, http://www.apache.org/

Benchmarking 127.0.0.1 (be patient)
Completed 500 requests
Completed 1000 requests
Completed 1500 requests
Completed 2000 requests
Completed 2500 requests
Completed 3000 requests
Completed 3500 requests
Completed 4000 requests
Completed 4500 requests
Completed 5000 requests
Finished 5000 requests


Server Software:
Server Hostname: 127.0.0.1
Server Port: 65420
SSL/TLS Protocol: TLSv1/SSLv3,ECDHE-RSA-AES128-GCM-SHA256,4096,128

Document Path: /
Document Length: 11 bytes

Concurrency Level: 250
Time taken for tests: 34.688 seconds
Complete requests: 5000
Failed requests: 0
Write errors: 0
Keep-Alive requests: 0
Total transferred: 460000 bytes
HTML transferred: 55000 bytes
Requests per second: 144.14 [#/sec] (mean)
Time per request: 1734.425 [ms] (mean)
Time per request: 6.938 [ms] (mean, across all concurrent
requests)
Transfer rate: 12.95 [Kbytes/sec] received

Connection Times (ms)
min mean[+/-sd] median max
Connect: 326 1057 236.0 1042 1709
Processing: 35 658 210.9 660 1013
Waiting: 35 658 211.1 659 1012
Total: 1264 1716 109.3 1702 2651

Percentage of the requests served within a certain time (ms)
50% 1702
66% 1708
75% 1712
80% 1714
90% 1720
95% 1779
98% 2158
99% 2211
100% 2651 (longest request)






That's much worse than I expected it to be. ~144 requests per second
instead of
42*k*. That's more than 99% performance drop. The cipher a moderate but
secure
(for now), I doubt that changing the cipher will help a lot here. nginx
and HAProxy
performance is almost equal so it's not a problem with the server
software.
One could increase nbproc (at least in my case it only increased up to
nbproc 4,
Xeon E3-1281 v3) but that's just a rather minor enhancement. With those
~144 r/s
you're basically lost when being under attack. How did you guys solve
this problem?
External SSL offloading, using hardware crypto foo, special
cipher/settings tuning,
simply *much* more hardware or not yet at all?

--
Regards,
Christian Ruppert

RE: Avaya Users (no replies)

$
0
0
Hi,



Would you be interested in reaching out to "Avaya Users List" with opt-in
verified contact information? to market your products and services?



We also have data for Avaya Aura Users, Avaya Aura Application Enablement
Services (AES) Users, Avaya Aura Contact Center Users, Avaya Aura Experience
Portal (Voice Portal) Users, Avaya Call Center Users, Avaya Call Center
Automatic Call Distribution (ACD) Users, Avaya Call Management System (CMS)
Users, Avaya CentreVu Supervisor Users, Avaya Communication Manager (ACM)
Users, Avaya Definity Users, Avaya Interaction Center Users, Avaya Intuity
Users, Avaya IP Agent Users, Avaya IP Office Users, Avaya IP Telephony
(VoIP) Users, Avaya IVR Users, Avaya Media Gateways Users, Avaya Media
Servers Users, Avaya Modular Messaging Users, Avaya Network Hardware Users,
Avaya Octel Users, Avaya one-X Users, Avaya PBX Users, Avaya Site
Administration Users, Avaya Telephony Users, Avaya Unified Communications
Users, Avaya Voice Mail Users, Avaya Voice Platform Users and more..



We as a leading Technology database compiler can assist you with contacts of
IT Decision Makers like CEO's, CSO's, CFO's, CMO's, CIO, CTO, VP of IT, IT
Directors, IT Managers, Architechts, Project Managers, VP of IT
infrastructure, DBAs, Analysts, Datacenter Managers, Product Managers,
Engineers, Designers, Virtualization Directors, Cloud Directors and many
more.



We can provide email/phone list for any niche technology criteria across USA
and UK. Every record is 100% CAN SPAM Compliant and is a result of email
survey and telephonic confirmation.



Hit reply and send in your target criteria accordingly I can provide you
with counts and a few demo samples to prove the accuracy of our data.



If this email is not concern to you, then kindly forward it to the right
person.



Thanks and look forward for your response!



Best Regards,

Gina Myers



We respect your privacy, if you do not wish to receive any further emails
from our end, please reply with a subject "Leave Out".

[SPAM] Remettez à neuf votre canapé affaissé avec le Redresse Fauteuil (no replies)

$
0
0
Si ce message ne s'affiche pas correctement, cliquez ici



























&#160;
&#160;
&#160;
&#160;


&#160;
&#160;





REDRESSE FAUTEUIL






- 50%






19,95 &#8364;
9,99 &#8364;




&#160;
&#160;



&#160;
&#160;
&#160;
&#160;


&#160;
&#160;





&#160;

&#160;



&#160;
- Réhausse les fauteuils
- Redonne fermeté et confort
- Retrouvez une assise ferme et confortable
&#160;




EN SAVOIR PLUS




&#160;



&#160;
&#160;
&#160;





&#160;
&#160;


&#160;
&#160;

&#160;
&#160;














&#160;
&#160;
&#160;
&#160;


&#160;
&#160;





PACK AMPOULES LED PORTABLE





- 60%






19,90 &#8364;
7,99 &#8364;




&#160;
&#160;



&#160;
&#160;
&#160;
&#160;


&#160;
&#160;





&#160;

&#160;



&#160;
- Dispose de 3 LED de lumière blanche et d'un autocollant
- S'active et se désactive en tirant sur la corde qui pend
- Une ampoule qui s'installe n'importe où
&#160;




EN SAVOIR PLUS




&#160;



&#160;
&#160;
&#160;





&#160;
&#160;


&#160;
&#160;

&#160;
&#160;















&#160;

&#160;




&#160;












-71%


19,99 &#8364;









BATTERIE DE SECOURS VOITURE - START GENIE









EN SAVOIR PLUS











&#160;











-55%

17,96 &#8364;













FEUILLE DE CUISSON SILICONE 1 ACHETEE = 1 OFFERTE













EN SAVOIR PLUS












&#160;


&#160;


&#160;


&#160;








&#160;

&#160;




&#160;












-50%

9,99 &#8364;









JEGGING BEAUTY JEANS









EN SAVOIR PLUS











&#160;











-61%

9,99 &#8364;













LOT DE 6 ALWAYS FRESH EGGS 1 LOT ACHETE = 1 LOT OFFERT













EN SAVOIR PLUS












&#160;


&#160;


&#160;


&#160;













Voir la version en ligneSe désinscrire

startseite professional hardware manufacturer since 2004 (no replies)

$
0
0
To:Managerdirector Wearetheglasshardwaremanufacturer=forover10years.Wecandomoreasyourexpecting.=1.Wehavestockforurgentorder.Weca=ngetready200pcsglasshardwarein7days.2.Youdon'tworryaboutthequalityand=youcangetyearsguaranteefromus.3.Wehavesuppliedourproductstomany=over5starslevelhotelallovertheworld.4.Thefinishoftheproductscanpasss=altyspraytest.5.Thematerialissolidcopperbrass.Ifyouwanttogetmoreinformat=ionaboutusandourwebsite,pleasecontactus.Thanks. Wealsohaveotherbuildinghardware,Ourproductrangesinclude:-Stainless=steelhinges;brasshingesandironhinges. &nbs=p; &n=bsp; -Hinges&am=p;accessoriesforshowerdoorsandpanels. &nbs=p; &n=bsp; -Floordrai=n. &nbs=p; &n=bsp; -Handles&a=mp;knobsforshowerdoor. &nbs=p; &n=bsp; -Architectu=ralhardwareitemssuchasdoorstop,doorviewer, &n=bsp; &nbs=p; &n=bsp; door=guard etc. &nbs=p; &n=bsp; -Furniture=hardwaresuchashandle,knob,slidingrail, &n=bsp; &nbs=p; &n=bsp; conce=aledhinges..etc &nbs=p; &n=bsp; -Curtainha=nger. &nbs=p; &n=bsp; -Clothhook=. &nbs=p; &n=bsp; -Hangwheel=forslidingdoor. &nbs=p; &n=bsp; -Washroomc=ubicle&amp;partitionfittings. &nbs=p; &n=bsp; -Solidstee=lleverlockandsolidbrassleverlock. &nbs=p; &n=bsp; -Mortiselo=ckcase,EuropeanandAmericantype. &nbs=p; &n=bsp; -Solidstee=lwindowhandleandsolidbrassleverhandle. &nbs=p; &n=bsp; -Solidstee=lpullhandleforentranceglassdoor. &nbs=p; &n=bsp; -Patchfitt=ings. &nbs=p; &n=bsp; -Stainless=steelelectronicdoorlock. Pleaseaskusformoreinformation. Bestregards Dans

SOCK-RAW (no replies)

$
0
0
This e-mail I got from your website: http://sock-raw.org
You write that you are engaged in network security.
I'm looking for products to protect computer networks LANthat I could sell in Poland (European Union).
I work in marketing and computer science for 17 years in the capital, Warsaw:(Windows Servers, Linux Servers, Oracle, MS SQL, network security: Fortinet and Linux)and I have contacts with several thousand companies IT in Poland.I sell computer equipment since 2004.
I also have the highest security certificate,which entitles me to the service of the government.I'm only interested exclusivity agreement in Poland.
Can you offer something what I need?
Andrzej SwietochowskiWarsaw / Poland European Union

using use_backend rules with map files (no replies)

$
0
0
Hello,

is it possible use use_backend rules with map files multiple times in
one frontend? My small example don't work. HAProxy returns 503, if no
match in the first map file. it would be great, if HAProxy can continue
the processing of the request.

Regards,
Michael

global
log /dev/log local0
log /dev/log local1 notice


defaults
mode http
timeout connect 5s
timeout client 15s
timeout server 15s


frontend http-in
bind :8080

use_backend bk_%[path,map_beg(/etc/haproxy/path2backends.map)]
use_backend
bk_%[req.hdr(host),lower,map(/etc/haproxy/host2backends.map,stats)]


backend bk_stats
stats enable
stats show-legends
stats realm Haproxy\ Statistics
stats uri /
stats refresh 30s


backend bk_host1
server a1 127.0.0.1:9001


backend bk_host2
server a2 127.0.0.1:9002


backend bk_path1
server a3 127.0.0.1:9003


backend bk_path2
server a4 127.0.0.1:9004

3D Visualization & Animation (no replies)

$
0
0
Dear Sir/Ms,

Hope you everything is great.
This is Zoe from Guangzhou SA Digital Technology.
We work on 3D rendering ,3D animation for architectural projects with more than ten years experience.
Kindly attached our website and Behance for your reference.
Are there any projects you are working on?
Pls feel free to contact me if you are interested in our 3D service.
Hope can receive your request soon.

Best regards,
Zoe
International Services Dept.
SA Digital Technology
Mob: +86-13431612298 Tel: +86-020-28976062
Skype ID: zoechow23 Email: zoe.chow@sa-cn.com
Add: Room1804 King Platinum International, NO.699-13 Dongfeng Dong Rd., Yuexiu District, Guangzhou, China
P"Please consider your environmental responsibility before printing this e-mail"

RE:Yindu hydraulic tools (no replies)

$
0
0
Dear Purchase Manager
&nbsp;&nbsp;&nbsp;&nbsp; Nice to me you,i am Ali Wang from Yindu Tools.
If you&nbsp;are going to purchase new order of&nbsp;hydraulic tools,hydraulic pumps,
Hydraulic cylinders,Busbar processor machines,etc for your new year market.
&nbsp;&nbsp;&nbsp;please reply me.
Thank you.
Best wishes
&nbsp;
Ali Wang
&nbsp;
http://www.yindutool.com
http://www.yindutools.com
Skype:alihydraulic
Tel:86-576-87419215
FAX:86-576-87419216
Mobile:86-18958615952
Wechat:542380901
whatsapp:0086-18767620666
Yuhuan Yindu hydraulic tools factory
Pengzhai industrial zone,Yuhuan,Taizhou,Zhejiang,China

CE278A 3.84USD / hot model toner cartridges bring you many customers (no replies)

$
0
0
Dear manager,How are you doing?We are toner cartridges manufacturer in Zhuhai with 11 years experiences and capacity of 500.000 PCS per month. We use top grade raw materials like Tomoegawa toner powder,Mitsubish OPC etc. In addition,we carry out 4 times quality control in incoming material,online production, finish production and outgoing.Our prices are also very competitive because our factory is located in an economic industry zone of Zhuhai, China.Please find bellow quotations for some popular items:CE285A&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; 3.84 USD&nbsp; CE505A&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; 5.36 USDQ5949A&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; 5.57 USDMLT-D111S&nbsp;&nbsp; 7.1&nbsp; USDFX-9&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; 3.84 USD&nbsp; &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; We have all the hot and new toner models that other suppliers do not have. If you&nbsp;are interested in&nbsp;any item please do tell me. We believe you will enlarge your business when working with us.Warm regards.------------------Angelina Leung&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; Zhuhai A-shine Technology Co., Ltd.&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; Add: Building 4,No.449 Gangchang Road,&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; Xiangzhou, Zhuhai,Guangdong, China.&nbsp; Skype:&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; queen.of.rain.100Whatsapp: 86-15989753586Mobile:&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; 86-15989753586Tel:&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; 86-756-6881078Web:&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; www.ashineprint.com&nbsp;

[SPAM] Fashion Days : jusqu'à -50% sur une sélection d'articles (no replies)

$
0
0
Afficher la version web. (http://trk.mix.espoir17.com/view/zJ3-63DIk.php) | Annuler votre abonnement. (http://trk.mix.espoir17.com/usb/zJ3-63DIk.php) | Signaler comme courrier indésirable. (mailto:abuse@dgcnit.fr)

http://trk.mix.espoir17.com/tk/zJ3-63DIk-AF5.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AF2.php http://trk.mix.espoir17.com/tk/zJ3-63DIk-AF0.php http://trk.mix.espoir17.com/tk/zJ3-63DIk-AF1.php http://trk.mix.espoir17.com/tk/zJ3-63DIk-AET.php http://trk.mix.espoir17.com/tk/zJ3-63DIk-AF6.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEW.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEO.php http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEP.php http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEQ.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEK.php http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEL.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEW.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEY.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEY.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEY.php http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEY.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEY.php http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEN.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AES.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AES.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AES.php http://trk.mix.espoir17.com/tk/zJ3-63DIk-AES.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AER.php http://trk.mix.espoir17.com/tk/zJ3-63DIk-AES.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEX.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEX.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEX.php http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEX.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEX.php http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEI.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEZ.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEZ.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEZ.php http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEZ.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEM.php http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEZ.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEV.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEV.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEV.php http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEV.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEV.php http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEJ.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEU.php
restez connectées http://trk.mix.espoir17.com/tk/zJ3-63DIk-nh1.php http://trk.mix.espoir17.com/tk/zJ3-63DIk-nh2.php http://trk.mix.espoir17.com/tk/zJ3-63DIk-nh3.php http://trk.mix.espoir17.com/tk/zJ3-63DIk-AEF.php http://trk.mix.espoir17.com/tk/zJ3-63DIk-hBP.php 123FrParis/posts
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AF3.php
http://trk.mix.espoir17.com/tk/zJ3-63DIk-AF4.php
Vous recevez cet e-mail car vous êtes référencé sur la base de données de notre partenaire XXXXXXXXX.

Conformément à la loi &quot;Informatique et Liberté&quot; n° 78-17 du 6 janvier 1978 modifiée, vous bénéficiez d'un droit d'accès, de rectification, d'opposition et de suppression des données vous concernant.
Vous souhaitez vous désinscrire de cette liste ? Cliquez ici. (http://trk.mix.espoir17.com/usb/zJ3-63DIk.php)

HAProxy Configuration Best Practices (no replies)

$
0
0
Hello,

I am in the middle of a project where I have to setup a couple of load balancers to allow load balancing traffic to some web app servers and to provide an easy way to swap out some other resources. I have spent a lot of time researching options and I settled on HAProxy with Keepalived to make it fault tolerant.

I have read through the HAProxy configuration options page as best I could and I have the basic setup of HAProxy for a web server. I also setup the stats option on the server. Do you have any tips or resources on what best practices are for the haproxy.cfg file? Most options I find are basic with the front and back end setup, the binding IP, the server list, and the method used for load balancing. Is there anything else I should add to that basic configuration? Is there an easy way to tell what the connection counts should be? Any info would be greatly appreciated.

Thanks for your time.

Regards


[signatureSeal]Gregg Cranshaw
Senior Network Engineer
RI Department of State | Secretary of State Nellie M. Gorbea
Email: g<mailto:cvillandry@sos.ri.gov>cranshaw@sos.ri.gov | Website: www.sos.ri.gov | Twitter: @RISecStatehttps://twitter.com/RISecState
148 W. River Street, Providence RI 02904 | 401-222-1326

Our Mission: The Rhode Island Department of State engages and empowers all Rhode Islanders by making government more accessible and transparent, encouraging civic pride, enhancing commerce and ensuring that elections are fair, fast and accurate.

A HAProxy statistics collection program (1 reply)

$
0
0
Hi all,

I would like to announce a statistics collector program for HAProxy.

Key features:
- Support of multiprocess mode of HAProxy (nbproc > 1)
- Ability to pull statistics at very low intervals even when there
are thousands for servers/backends.

It has been already used in production environments and produces 200K
metrics per interval (10secs).

It can be found here:
https://github.com/unixsurfer/haproxystats

I hope it will be useful for other people as well.

Cheers,
Pavlos

SSL and SNI keeping it all in HAProxy (no replies)

IDEA: initial-state up/down option for servers (2 replies)

$
0
0
Hi,

We use haproxy in an auto-scaling environment. On an auto-scaling event, the haproxy configuration is rewritten to list all existing servers for each proxied service. A graceful reload is then performed.

The issue is that by default haproxy assumes a server is UP (going down) until the first healthcheck tells it otherwise. If one of the servers for a proxy/backend is not yet actually healthy (e.g. in the initial moments after a new instance is booted), then some requests will be forwarded to the new instance, resulting in 503 responses.

This was a must before 1.6’s server-state-file feature as we’d not want everything to be marked down for a few seconds after a reload. However when using a server-state-file we know the state of every server other than any new ones. We’d like these new ones to be marked DOWN (going up) so they do not receive requests until the first healthcheck is passed.

We’re currently testing a patch which adds an “initial-state up/down” option to each server (and the default-server option) - the default behaviour remains unchanged:
https://github.com/beamly/haproxy-1.6/commit/9e7ad68a0c6582a38591eb27626fdb31bb5f8c18

I’m wondering if this is something that could be considered for a future haproxy release?

Many thanks,
Chris
Viewing all 5112 articles
Browse latest View live




Latest Images